@@ -11,17 +11,17 @@ from . import github
 ## PUBLIC
 ##
 
-def notify_prerelease(project, repo, prerelease_version):
-    url = _get_project_webhook_url(project)
-    text = notify_prerelease_text(repo, prerelease_version)
+def notify_prerelease(project_name, repo, prerelease_version):
+    url = _get_project_webhook_url(project_name)
+    text = notify_prerelease_text(project_name, repo, prerelease_version)
 
     _send_message(url, text)
 
-def notify_prerelease_text(repo, prerelease_version):
+def notify_prerelease_text(project_name, repo, prerelease_version):
     commits = github.commits_between_prerelease_and_latest_release(repo, prerelease_version)
 
     message = f"""
-<!here> *API pre-release :rocket:*
+<!here> *{project_name.upper()} pre-release :rocket:*
 
 <https://github.com/{repo.full_name}/releases/tag/{prerelease_version}|*{prerelease_version}*>
 {_message_links(commits)}
@@ -31,17 +31,17 @@ def notify_prerelease_text(repo, prerelease_version):
 
     return message
 
-def notify_release(project, repo, release_version):
-    url = _get_project_webhook_url(project)
-    text = notify_release_text(repo, release_version)
+def notify_release(project_name, repo, release_version):
+    url = _get_project_webhook_url(project_name)
+    text = notify_release_text(project_name, repo, release_version)
 
     _send_message(url, text)
 
-def notify_release_text(repo, release_version):
+def notify_release_text(project_name, repo, release_version):
     commits = github.commits_between_prerelease_and_latest_release(repo, release_version)
 
     message = f"""
-<!here> *API release :rocket:*
+<!here> *{project_name.upper()} release :rocket:*
 
 <https://github.com/{repo.full_name}/releases/tag/{release_version}|*{release_version}*>
 {_message_links(commits)}
@@ -76,14 +76,14 @@ def _message_links(commits):
 
     return '\n'.join(message_links_unique)
 
-def notify_prerelease_error(project, repo, version, pulls):
+def notify_prerelease_error(project_name, repo, version, pulls):
     message_links = ''
 
     for pull in pulls:
         message_links += f'- <https://github.com/{repo.full_name}/pull/{pull.number}|{pull.title}> ({_get_slack_user_id(pull.user.login)})\n'
 
     text = f"""
-<!here> *API pre-release FAILED :warning:*
+<!here> *{project_name.upper()} pre-release FAILED :warning:*
 
 <https://github.com/{repo.full_name}/releases/tag/{version}|*{version}*>
 {message_links}
@@ -91,18 +91,18 @@ def notify_prerelease_error(project, repo, version, pulls):
 {_message_footer()}
     """
 
-    url = _get_project_webhook_url(project)
+    url = _get_project_webhook_url(project_name)
 
     _send_message(url, text)
 
-def notify_release_error(project, repo, version, pulls):
+def notify_release_error(project_name, repo, version, pulls):
     message_links = ''
 
     for pull in pulls:
         message_links += f'- <https://github.com/{repo.full_name}/pull/{pull.number}|{pull.title}> ({_get_slack_user_id(pull.user.login)})\n'
 
     text = f"""
-<!here> *API release FAILED :warning:*
+<!here> *{project_name.upper()} release FAILED :warning:*
 
 <https://github.com/{repo.full_name}/releases/tag/{version}|*{version}*>
 {message_links}
@@ -110,7 +110,7 @@ def notify_release_error(project, repo, version, pulls):
 {_message_footer()}
     """
 
-    url = _get_project_webhook_url(project)
+    url = _get_project_webhook_url(project_name)
 
     _send_message(url, text)
 
@@ -138,12 +138,12 @@ def _get_slack_user_id(github_login):
     except KeyError:
         return github_login
 
-def _get_project_webhook_url(project):
+def _get_project_webhook_url(project_name):
     with open('./config/projects.yml', 'r', encoding='utf-8') as stream:
         try:
             config = yaml.safe_load(stream)
 
-            return config[project]['slack_webhook_url']
+            return config[project_name]['slack_webhook_url']
         except (KeyError, yaml.YAMLError):
             print("\njavelin: invalid project name")
             sys.exit(2)
